function plotMCMC( statesSpace, states )

% ============================================================================
% DESCRIPTION
%
% usage: plotMCMC( statesSpace, states )
%
% Plot the estimated stationary probabilities over time
%
% ----------------------------------------------------------------------------
% PARAMETERS
%
%  statesSpace                 a row vector (of size J) containing the states space of the system
%  states                      a row vector with the state of the system at every step.
%                              The states should be the same listed in statesSpace
%
% ---------------------------------------------------------------------------
% RETURN VALUES
%
% 
% ============================================================================


states_indx = [];
for i=1:size(states,2)
    index = find(contains(statesSpace,states(i)));
    states_indx = [states_indx index];
end

plot(states_indx,'ok');
yticks([1:size(statesSpace,1)]);
yticklabels(statesSpace);


% stationary probabilities
ps = [];
p = zeros(size(statesSpace,1),1);
for i=1:size(states,2)
    index = find(contains(statesSpace,states(i)));
    p(index) = p(index)+1;
    ps = [ps p];
end

% tranform in probability
for i=1:size(states,2)
    ps(:,i) = ps(:,i)/i;
end

plot(ps')
legend(statesSpace);

end
